import { Service } from "../service";
import { MongodbService } from "./mongodbService";
import { AuthenticationService, AuthenticationData } from "./authenticationService";
import * as mongodb from "mongodb";
import * as Leaf from "leaf-ts";
export declare type Callback<T> = (err?: Error, result?: T) => void;
export declare const Errors: {
    NotFound: Leaf.CustomErrorConstructor<{}>;
    UnknownError: Leaf.CustomErrorConstructor<{}>;
    DBError: Leaf.CustomErrorConstructor<{}>;
    AlreadyExists: Leaf.CustomErrorConstructor<{}>;
    InvalidParameter: Leaf.CustomErrorConstructor<{}>;
    NameAlreadyExists: Leaf.CustomErrorConstructor<{}>;
    EmailAlreadyExists: Leaf.CustomErrorConstructor<{}>;
};
export declare class AccountService<TAccountDefinition extends AccountDefinition = AccountDefinition> extends Service {
    readonly name: string;
    protected collectionName: string;
    readonly dependencies: string[];
    services: {
        MongodbService: MongodbService;
        AuthenticationService: AuthenticationService;
    };
    accountCollection: mongodb.Collection;
    initialize(done: any): void;
    createFromAuthentication(option: {
        authentication: AuthenticationData;
        id?: string;
        name?: string;
        displayName?: string;
        props?: TAccountDefinition["props"];
        role?: TAccountDefinition["role"];
    }, callback: Callback<TAccountDefinition>): void;
    get(id: string, callback: Callback<TAccountDefinition>): void;
    update(option: {
        account: TAccountDefinition;
        mongoUpdates?: any;
    }, callback: Callback<TAccountDefinition>): void;
}
export interface AccountDefinition {
    id: string;
    name: string;
    displayName: string;
    role?: string;
    props?: any;
}
